:orphan:

========================================
OpenERP Server Developers Documentation
========================================

OpenERP Server
''''''''''''''

.. toctree::
   :maxdepth: 2

   01_getting_started
   02_architecture
   03_module_dev
   04_security
   05_test_framework
   06_misc
   09_deployment

OpenERP Server API
''''''''''''''''''

.. toctree::
   :maxdepth: 1

   api_core.rst
   api_models.rst

Concepts
''''''''

.. glossary::

    Database ID

        The primary key of a record in a PostgreSQL table (or a
        virtual version thereof), usually varies from one database to
        the next.

    External ID
